Author: Jean-Philippe Meuret
Keywords: distance, sampling, mcds, pre-analysis, ACDC, Cournols, Olloix, 2019, Distance Sampling, Naturalist, smartphone

ACDC 2019 Naturalist
Pre-analysis report
Estimation of common breeding bird populations on the Cournols - Olloix plateau - in 2019 though ~100 distance sampling point transects of 5 and 10mn (2 seasonal passes) ; using the Naturalist smartphone app. for field surveys
Warning: This is only an extract of the actual report, limited to 2 species

#### Table of contents

- Results: the essence
- Traceability

## Results: the essence

Study type: Point transect, Radial distance, No clustering.

Units used: Meter for distances, Sq. Kilometer for areas.

Confidence value interval: If not listed in table below, please note that ALL analyses have been run with the same value: 95 .

Adjustment term selection criterion: If not listed in table below, please note that ALL analyses have been run with the same value: AIC .

Note: Most figures have been rounded for readability, but 'CoefVar Density' have been further modified : converted to %

Click on analysis number to get to detailed report

| Sample & Model | Results (1/2) | Results (2/2) | Standard distance histogram | Detection probability density (PDF) | Detection probability
--- | --- | --- | --- | --- | --- | ---
02 |
Echant | 1
Espèce | Sylvia atricapilla
Passage | a+b
Adulte | m
Durée | 10mn
Mod Key Fn | HAZARD
Mod Adj Ser | COSINE
ExCod | 2
NObs | 403
Max Dist | 511.41
Effort | 190
AIC | 4526.8
Chi2 P | 0
KS P | 0.52
CoefVar Density | 9.9
PDetec | 0.07
EDR/ESW | 135.2
Density | 36.95
Min Density | 30.45
Max Density | 44.85
Number | 887
Min Number | 731
Max Number | 1076
04 |
Echant | 3
Espèce | Prunella modularis
Passage | a+b
Adulte | m
Durée | 10mn
Mod Key Fn | UNIFORM
Mod Adj Ser | COSINE
ExCod | 2
NObs | 47
Max Dist | 271.221
Effort | 190
AIC | 494.6
Chi2 P | 0.21
KS P | 0.47
CoefVar Density | 24.2
PDetec | 0.172
EDR/ESW | 112.4
Density | 6.24
Min Density | 3.89
Max Density | 9.99
Number | 150
Min Number | 93
Max Number | 240

## Traceability

### Samples

| Espèce | Passage | Adulte | Durée | Abrev. Echant | Echant
--- | --- | --- | --- | --- | --- | ---
1 | Sylvia atricapilla | a+b | m | 10mn | SylvAtri-ab-10mn-m | 1
3 | Prunella modularis | a+b | m | 10mn | PrunModu-ab-10mn-m | 3

### Models

| keyFn | adjSr | estCrit | cvInt
--- | --- | --- | --- | ---
0 | HNORMAL | COSINE | AIC | 95
1 | UNIFORM | COSINE | AIC | 95
2 | HAZARD | COSINE | AIC | 95
3 | HNORMAL | POLY | AIC | 95
4 | UNIFORM | POLY | AIC | 95
5 | HAZARD | POLY | AIC | 95

### Analyser

| Value
--- | ---
Zone | ACDC
Surface | 24
distanceUnit | Meter
areaUnit | Sq. Kilometer
runMethod | subprocess.run
runTimeOut | 300
surveyType | Point
distanceType | Radial
clustering | False
defEstimKeyFn | UNIFORM
defEstimAdjustFn | POLY
defEstimCriterion | AIC
defCVInterval | 95
defMinDist | None
defMaxDist | None
defFitDistCuts | None
defDiscrDistCuts | None

### Computing platform

| Version
--- | ---
os | Windows Enterprise 10.0.19041 (64bit)
processor | Intel64 Family 6 Model 165 Stepping 2, GenuineIntel, 12 CPUs
python | cpython (win32) R3.8.2 | packaged by conda-forge | (default, Apr 24 2020, 07:34:03) [MSC v.1916 64 bit (AMD64)]
numpy | 1.23.2
pandas | 1.2.5
zoopt | 0.4.0
matplotlib | 3.4.2
jinja2 | 3.0.1
pyaudisam | 1.0.0
DS engine | C:/PortableApps/Distance 7/MCDS.exe

###### Generated on 16/04/2023 18:55:51 with Python 3.8.2, NumPy 1.23.2, Pandas 1.2.5, ZOOpt 0.4.0, Matplotlib 3.4.2, Jinja 3.0.1 ... and PyAuDiSam 1.0.0, with icons from Font Awesome (sources : acdc-2019-nat-ds-params.py, ) .